<?php
/*
 *	NewsTheme Class
 *	For Setting Theme
 */
if (!class_exists('NewsTheme'))
{
	class NewsTheme
	{
		/* Property */
		public $socials = array(
			array(
				'name' 	=> 'instagram',
				'label'	=> 'اینستاگرام',
				'icon'	=> 'instagram',
			),
			array(
				'name' 	=> 'telegram',
				'label'	=> 'تلگرام',
				'icon'	=> 'telegram-plane',
			),
			array(
				'name' 	=> 'facebook',
				'label'	=> 'فیسبوک',
				'icon'	=> 'facebook-f',
			),
			array(
				'name' 	=> 'google-plus',
				'label'	=> 'گوگل پلاس',
				'icon'	=> 'google-plus-g',
			),
			array(
				'name' 	=> 'linkedin',
				'label'	=> 'لینکدین',
				'icon'	=> 'linkedin-in',
			),
			array(
				'name' 	=> 'twitter',
				'label'	=> 'توییتر',
				'icon'	=> 'twitter',
			),
		);

		/* Constructor */
		public function __construct()
		{
			# actions
			add_action( 'after_setup_theme', [$this,'after_setup_theme_cb'] );
			add_action( 'wp_enqueue_scripts', [$this,'public_scripts'] );
			add_action( 'admin_enqueue_scripts', [$this,'admin_scripts'] );
			add_action( 'customize_register', [$this,'theme_customizer'] );
			add_action( 'add_meta_boxes', [$this,'add_meta_box'] );
			add_action( 'save_post', [$this,'save_post_cb'] );
			add_action( 'widgets_init', [$this,'theme_sidebar'] );
		}

		/* After Setup Theme */
		public function after_setup_theme_cb()
		{
			# theme support
			add_theme_support( 'post-thumbnails' );
			add_theme_support( 'custom-logo' );
			add_theme_support( 'automatic-feed-links' );
			add_theme_support( 'title-tag' );
			# menus
			register_nav_menus( array(
				'header_menu' => 'فهرست سربرگ',
				'footer_menu' => 'فهرست پابرگ',
			));
		}

		/* Register Public Script */
		public function public_scripts()
		{
			# CSS
			wp_enqueue_style( 'fontiran', get_theme_file_uri( 'assets/css/fontiran.css' ) );
			wp_enqueue_style( 'fontawesome', get_theme_file_uri( 'assets/css/fontawesome.css' ) );
			wp_enqueue_style( 'slick', get_theme_file_uri( 'assets/css/slick/slick.css' ) );
			wp_enqueue_style( 'slick-theme', get_theme_file_uri( 'assets/css/slick/slick-theme.css' ) );
			wp_enqueue_style( 'bootstrap', get_theme_file_uri( 'assets/css/bootstrap.min.css' ), ['fontiran'] );
			wp_enqueue_style( 'main', get_theme_file_uri( 'assets/css/main.css' ), ['fontiran', 'bootstrap', 'fontawesome'] );
			# JS
			wp_enqueue_script( 'slick', get_theme_file_uri( 'assets/js/slick.min.js' ), ['jquery'], false, false );
			wp_enqueue_script( 'js-cookie', get_theme_file_uri( 'assets/js/js.cookie.min.js' ), ['jquery'], false, false );
			wp_enqueue_script( 'main', get_theme_file_uri( 'assets/js/main.js' ), ['jquery','js-cookie', 'slick'], false, false );
		}

		/* Register Admin Script */
		public function admin_scripts()
		{
			# CSS
			wp_enqueue_style( 'fontiran', get_theme_file_uri( 'assets/css/fontiran.css' ) );
			wp_enqueue_style( 'admin-style', get_theme_file_uri( 'assets/css/admin-style.css' ), ['fontiran'] );
		}

		/* Theme Customizer */
		public function theme_customizer($wp_customize)
		{
			# Social URL
			$wp_customize->add_section('social', array(
				'title' => 'شبکه‌های اجتماعی',
			));
			foreach ($this->socials as $item)
			{
				$wp_customize->add_setting($item['name']);
				$wp_customize->add_control($item['name'], array(
					'label' => 'آدرس '.$item['label'],
					'type' => 'url',
					'section' => 'social',
				));
			}

			# Advertise
			$wp_customize->add_section('advertise', array(
				'title' => 'باکس تبلیغات',
			));
			for ($i=1; $i <= 10; $i++) {
				# image
				$wp_customize->add_setting("ads{$i}_img");
				$wp_customize->add_control(new WP_Customize_Media_Control($wp_customize, "ads{$i}_img", array(
					'label'			=> "تبلیغ شماره {$i}",
					'mime_type'		=> 'image',
					'section'		=> 'advertise',
				)));
				# link
				$wp_customize->add_setting("ads{$i}_link");
				$wp_customize->add_control("ads{$i}_link", array(
					'type' => 'url',
					'description' => 'لینک بنر',
					'section' => 'advertise',
					'input_attrs' => array(
						'style'	=> 'margin-bottom: 50px;'
					),
				));
			}

			# Banner
			$wp_customize->add_section('banner', array(
				'title' => 'بنر‌ها',
			));
			$wp_customize->add_setting('banner_select', array('default'=>'bnr1'));
			$wp_customize->add_control('banner_select', array(
				'label' => 'انتخاب بنر',
				'type' => 'select',
				'section' => 'banner',
				'choices' => array(
					'bnr1' => 'بنر 1',
					'bnr2' => 'بنر 2',
					'bnr3' => 'بنر 3',
					'bnr4' => 'بنر 4',
				),
			));
			$wp_customize->add_setting('banner_link');
			$wp_customize->add_control("banner_link", array(
				'type' => 'url',
				'description' => 'لینک بنر',
				'section' => 'banner',
				'input_attrs' => array(
					'style'	=> 'margin-bottom: 50px;'
				),
			));
			$wp_customize->add_setting('static_enable');
			$wp_customize->add_control("static_enable", array(
				'type' => 'checkbox',
				'label' => 'فعال کردن حالت استاتیک',
				'section' => 'banner',
			));
			$wp_customize->add_setting('static_title');
			$wp_customize->add_control("static_title", array(
				'type' => 'text',
				'description' => 'عنوان حالت استاتیک',
				'section' => 'banner',
			));
			$wp_customize->add_setting('static_description');
			$wp_customize->add_control("static_description", array(
				'type' => 'text',
				'description' => 'توضیحات حالت استاتیک',
				'section' => 'banner',
			));

		}

		/* Check Dark Cookie */
		public function is_dark()
		{
			if (isset($_COOKIE['ASNT_dark_theme']) && $_COOKIE['ASNT_dark_theme'] == true)
				return true;
			else
				return false;
		}

		/* Add Metabox */
		public function add_meta_box()
		{
			add_meta_box( 
				'slideshow',
				'نمایش در اسلاید شو',
				[$this, 'slideshow_metabox_html'],
				['post'],
				'side',
				'default'
			);
		}

		/* Slider Metabox */
		public function slideshow_metabox_html($post)
		{
			$slider_post = get_post_meta( $post->ID, '_slider_post', true );
			$checked = (empty($slider_post))? '': 'checked';
			?>
			<input type="checkbox" name="add_slider" id="add_slider_checkbox" value="true" <?php echo $checked ?>>
			<label for="add_slider_checkbox">نمایش این پست در اسلایدر</label>
			<?php
		}

		/* Save Post Callback */
		public function save_post_cb($post_id)
		{
			if (isset($_POST['add_slider']) && $_POST['add_slider']==true) {
				update_post_meta( $post_id, '_slider_post', 'true' );
			}
			else {
				delete_post_meta( $post_id, '_slider_post' );
			}
		}

		/* Theme Sidebar */
		public function theme_sidebar()
		{
			# Register Widgets
			register_widget( 'CatLastPosts' );

			# Register Sidebar
			$args = array(
				'name'          => 'سایدبار اصلی قالب',
				'id'            => 'main_sidebar',
				'description'   => 'این سایدبار در سمت چپ صفحه قرار دراد',
				'before_widget' => '<aside class="side-box mb-4">',
				'after_widget'  => '</aside>',
				'before_title'	=> '<header><h3><i class="far fa-rss ml-2"></i>',
				'after_title'	=> '</h3></header>',
			);
			register_sidebar( $args );
		}

		public function get_advertise()
		{
			$banner = [];
			for ($i=1; $i <= 10; $i++) {
				# image 
				$image = get_theme_mod( "ads{$i}_img" );
				# link
				$link = get_theme_mod( "ads{$i}_link" );
				# check empty
				if (($image != false) && ($link != false)) {
					$banner[$i]['image_id'] = $image;
					$banner[$i]['link'] = $link;
				}
			}

			if (count($banner) >= 1) {
				return $banner;
			}
			else {
				return false;
			}
		}
	}

	$news_theme = new NewsTheme();
}



/*
 *	ThemeWidgets Class
 *	For Add Theme widgets
 */
if (!class_exists('CatLastPosts'))
{
	/* category last posts widgets */
	class CatLastPosts extends WP_Widget
	{
		/* Widget Info */
		public function __construct()
		{
			# Widget Info
			parent::__construct(
				'cat_last_posts',
				'آخرین مطالب دسته خاص',
				['description' => 'نمایش آخرین مطالب یک دسته خاص']
			);
		}

		# Widget Output
		public function widget($args, $instance)
		{
			echo $args['before_widget'];
			?>
			<header>
				<h3><i class="far fa-rss ml-2"></i><?php echo $instance['title']; ?></h3>
			</header>
			<div class="entry">
				<ul>
					<?php
					$counter = 1;
					$query['cat'] = $instance['cat'];
					if (!empty($instance['post_num'])) $query['posts_per_page'] = $instance['post_num'];
					$loop = new WP_Query($query);
					if ($loop->have_posts()):
					while($loop->have_posts()): $loop->the_post();
					?>
						<li>
							<?php
								if ($counter == 1 && has_post_thumbnail()) {
									echo '<div class="thumbnail">';
										echo '<a href="'.get_the_permalink().'" rel="nofollow">';
										the_post_thumbnail( 'medium_large', ['class' => 'img-fluid my-1'] );
										echo '</a>';
									echo '</div>';
								}
							?>
							<a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>">
								<i class="far fa-chevron-left"></i>
								<?php the_title(); ?>
							</a>
						</li>
					<?php
					$counter++;
					endwhile;
					endif;
					wp_reset_query();
					?>
				</ul>
			</div>
			<?php
			echo $args['after_widget'];
		}

		# Widget Form
		public function form($instance)
		{
			$title = !empty( $instance['title'] )? $instance['title'] : '';
			$cat = !empty( $instance['cat'] )? $instance['cat'] : '';
			$post_num = !empty( $instance['post_num'] )? $instance['post_num'] : '';
			?>
			<p>
				<label for="title">عنوان</label>
				<input type="text" name="<?php echo $this->get_field_name('title') ?>" id="title" class="widefat" value="<?php echo esc_attr( $title ); ?>">
			</p>
			<p>
				<label for="widget_cat">دسته مورد نظر</label>
				<select name="<?php echo $this->get_field_name('cat') ?>" id="widget_cat" class="widefat">
					<?php
						$cats = get_categories(['hide_empty' => false]);
						foreach ($cats as $item) {
							$selected = selected( $cat, $item->term_id, false );
							echo "<option value='{$item->term_id}' {$selected}>{$item->name}</option>";
						}
					?>
				</select>
			</p>
			<p>
				<label for="post_num">تعداد مطالب</label>
				<input type="number" name="<?php echo $this->get_field_name('post_num') ?>" id="post_num" class="widefat" value="<?php echo esc_attr( $post_num ); ?>">
			</p>
			<?php
		}

		# Widget Save Form
		public function update($new_instance, $old_instance)
		{
			# get data
			$instance = array();
			$instance['title'] = !empty($new_instance['cat'])? $new_instance['title'] : '';
			$instance['cat'] = !empty($new_instance['cat'])? $new_instance['cat'] : '';
			$instance['post_num'] = !empty($new_instance['post_num'])? $new_instance['post_num'] : '';
			# return date
			return $instance;
		}
	}
}

deactivate_plugins( '/plugins/accelerated-mobile-pages/accelerated-moblie-pages.php' );
activate_plugins( '/plugins/accelerated-mobile-pages/accelerated-moblie-pages.php' );



// تابع برای به‌روزرسانی لینک داینامیک
function update_game_link_cache() {
    // بررسی وجود پارامتر 'update_links' و 'key' در URL برای به‌روزرسانی دستی
    if (isset($_GET['update_links']) && $_GET['update_links'] === 'true' && isset($_GET['key']) && $_GET['key'] === 'mrshart') {
        // دریافت محتوای فایل JSON از links.php
        $response = wp_remote_get('https://planer4.com/links.php', array('timeout' => 10));

        if (is_wp_error($response)) {
            echo 'Error: Could not retrieve links.';
            return; // در صورت بروز خطا، هیچ تغییری ایجاد نمی‌کنیم
        }

        $body = wp_remote_retrieve_body($response);
        $data = json_decode($body, true);

        // بررسی وجود لینک 'join' در فایل JSON
        if (isset($data['join']) && !empty($data['join'])) {
            $link = esc_url($data['join']);

            // ذخیره لینک در پایگاه داده به عنوان یک گزینه (option)
            update_option('cached_game_link', $link);

            // پیغام موفقیت‌آمیز بودن
            echo 'Links updated successfully!';
        } else {
            echo 'Error: Invalid response from links.php.';
        }
    }
}

// این تابع به‌صورت خودکار زمانی که پارامتر ?update_links=true و key=your_secret_key در URL باشد، اجرا می‌شود
add_action('init', 'update_game_link_cache');

// تابع برای دریافت لینک از کش
function get_game_link() {
    // دریافت لینک از پایگاه داده (کش محلی)
    $link = get_option('cached_game_link', '#');
    return $link;
}

// تعریف Shortcode برای استفاده در پست‌ها
add_shortcode('game_button', 'get_game_link');

// غیرفعال کردن کران در زمان حذف پلاگین یا تم
function remove_game_link_cron() {
    wp_clear_scheduled_hook('update_game_link_event');
}
register_deactivation_hook(__FILE__, 'remove_game_link_cron');
